#
# spec file for package python-flexx
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
%define         skip_python36 1
Name:           python-flexx
Version:        0.8.4
Release:        1.12
Summary:        Python toolkit for creating graphical user interfaces
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/flexxui/flexx
Source:         https://files.pythonhosted.org/packages/source/f/flexx/flexx-%{version}.tar.gz
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module dialite >= 0.5.2}
BuildRequires:  %{python_module imageio}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pscript >= 0.7.3}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module selenium}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tornado >= 4}
BuildRequires:  %{python_module webruntime >= 0.5.6}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-dialite >= 0.5.2
Requires:       python-pscript >= 0.7.3
Requires:       python-tornado
Requires:       python-webruntime >= 0.5.6
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-imageio
Recommends:     python-numpy
Recommends:     python-vispy
BuildArch:      noarch
%python_subpackages

%description
Flexx is a pure Python toolkit for creating graphical user interfaces
(GUIs), that uses web technology for its rendering. Apps are written
purely in Python; Flexx's transpiler generates the necessary JavaScript
on the fly.

Flexx can be used to create (cross platform) desktop applications, web
applications, and (if designed well) export an app to a standalone HTML
document. It also works in the Jupyter notebook.

%prep
%setup -q -n flexx-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/flexx
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Do not run tests, they require online access to jquery/etc.
#%%pytest

%post
%python_install_alternative flexx

%postun
%python_uninstall_alternative flexx

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/flexx
%{python_sitelib}/*

%changelog
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.8.4:
    There are small typos in:
  - docs/guide/widget_basics.rst
  - flexx/app/_session.py
  - flexx/app/tests/test_asset.py
  - flexx/event/_js.py
  - flexx/event/_reaction.py
  - flexx/ui/_widget.py
  - flexx/util/tests/test_config.py
  - flexxamples/howtos/echarts_example.py
  - flexxamples/testers/tricky_events.py
    Fixes:
  - Should read `precedence` rather than `precedense`.
  - Should read `assets` rather than `assests`.
  - Should read `simultaneously` rather than `simultenously`.
  - Should read `service` rather than `survice`.
  - Should read `occurrence` rather than `occurance`.
  - Should read `eliminate` rather than `elliminate`.
  - Should read `declarative` rather than `declerative`.
  - Should read `children` rather than `childen`.
  - Should read `capturing` rather than `caputuring`.
  - Should read `aggregated` rather than `agregated`.
    Some measures against memory leakage (#725)
  * fix memleak
  * help prevent rise in memory
  * quick check to see if this causes the ci test error
  * nope, error was already there
  * fix ci?
    Fix introducion of faulty JS (#710)
    Fix CI glitch properly (#706)
    Fix CI glitches (#705)
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 0.8.3:
  * Fixed a bug where with the latest PScript (0.7.6)
    Flexx wont start in the browser
* Wed Sep  1 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.8.2
  * Support for Python 3.9.
  * More symmetry between Py and Js widgets (#698)
  * A Flask server backend.
  * CI uses GH Actions instead of Travis.
- from version 0.8.1
  * Support for Python 3.8.
  * Support for latest Tornado (includes a workaround for py38+win).
  * Several fixes to various widgets.
  * Various fixes to the docs.
  * A few new examples.
- Update BuildRequires and Requires from setup.py
* Tue Feb 23 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 build (no numpy)
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue May  7 2019 pgajdos@suse.com
- version update to 0.8.0
  * Adds a `PyWidget` class that can be used as a base class for your high-level
    widgets. Because it is a PyComponent, this makes it much easier to write apps
    that fully work in Python (desktop-like apps).
  * The ``FormLayout`` uses CSS ``grid`` instead of ``<table>``.
  * A new ``GridLayout`` widget.
  * A new ``MultiLineEdit`` widget.
  * Improvements to docs and guide.
  * Support for freezing Flexx apps to standalone executables (via PyInstaller).
* Fri Mar 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix the URL
* Tue Mar 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.1:
  * Improved shutdown behavior (#533).
  * Small fix in App.export (#532).
  * Fix bahevior when navigating back to a Flexx app (#536).
  * New examples for Openlayers and including local assets (by @ocobacho).
  * Tests, demos and readme are included in the sdist, helping packaging on Linux (by @toddrme2178).
  * Some performance tweaks which should help in larger applications.
  * Add outernode attribute in TreeItem` widget, enabling more powerful subclasses.
  * The Combobox is smarter about the placement of the "dropdown".
  * A new RangeSlider widget.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Oct 29 2018 Todd R <toddrme2178@gmail.com>
- Update to version 0.6.2
  * Bugfix in combobox.
  * BSDF check dtype in JS.
- Update to version 0.6.0
  * Add ``Widget.minsize_from_children`` property (#497).
  * Update BSDF (data serialization).
  * Widgets van be orphaned upon initialization by setting parent to None (#493)
  * Some internal improvements on the dropdown widget.
- Update to version 0.5.0
  * A major refactoring of the event system.
  * We spun out the PyScript transpiler into the PScript project, as well
    as the webruntime and dialite project. This means that Flexx itself
    is focussed on the GUI aspect alone.
  * Added touch support.
  * Dropped the depency on Phosphor.js.
  * A new combined namespace: ``from flexx import flx``.
  * A proper guide in the docs.
  * More examples.
* Sat Mar  3 2018 jengelh@inai.de
- Summary and description improvements.
* Fri Dec  1 2017 toddrme2178@gmail.com
- intial version
